@@ -48,7 +48,9 @@ class CreateBranch:
         branch_name = prompt_utils.ask_questions_input(
             "Inserisci nome del branch: ",
             re.sub(
-                r'([\s\\.,~\^:\(\)\[\]\<\>"\'?]|[^\x00-\x7F])+', "-", issue["summary"],
+                r'([\s\\.,~\^:\(\)\[\]\<\>"\'?]|[^\x00-\x7F]|[0-9])+',
+                "-",
+                issue["summary"],
             ).lower(),
         )
 
