@@ -1,17 +1,11 @@
 # -*- encoding: utf-8 -*-
 from github import Github
-from suite_py.lib.tokens import Tokens
-from suite_py.lib.singleton import Singleton
 
 
-tokens = Tokens()
-
-
-class GithubHandler(metaclass=Singleton):
-    _client = None
+class GithubHandler:
     _organization = "primait"
 
-    def __init__(self):
+    def __init__(self, tokens):
         self._client = Github(tokens.github)
 
     def get_repo(self, repo_name):
