@@ -4,16 +4,10 @@ import os
 
 from PyInquirer import prompt
 
-from suite_py.lib.singleton import Singleton
-
 TOKENS = ["github", "youtrack", "drone"]
 
 
-class Tokens(metaclass=Singleton):
-    _file_name = None
-    _tokens = {}
-    _changed = False
-
+class Tokens:
     def __init__(self, file_name=os.path.join(os.environ["HOME"], ".suite_py/tokens")):
         self._file_name = file_name
         try:
@@ -21,6 +15,7 @@ class Tokens(metaclass=Singleton):
         except Exception:
             pass
 
+        self._changed = False
         self.check()
         if self._changed:
             self.save()
